import React, { Fragment } from 'react'
import { isEmpty, get } from 'lodash'

import {
  Text,
  Item,
  ContextualBox,
  ManuscriptFileList,
} from 'pubsweet-component-faraday-ui'

const ManuscriptMetadata = ({
  getSignedUrl,
  currentUser: { token },
  fragment: {
    files = {},
    authors = [],
    conflicts = {},
    metadata: { abstract = '' },
  },
}) => (
  <Fragment>
    {!!abstract && (
      <Item mb={1}>
        <ContextualBox label="Abstract" startExpanded transparent>
          <Text dangerouslySetInnerHTML={{ __html: abstract }} mb={1} mt={1} />
        </ContextualBox>
      </Item>
    )}
    {conflicts.hasConflicts === 'yes' && (
      <Item mb={1}>
        <ContextualBox label="Conflict of Interest" transparent>
          <Text
            dangerouslySetInnerHTML={{ __html: get(conflicts, 'message', '') }}
            mb={1}
            mt={1}
          />
        </ContextualBox>
      </Item>
    )}
    {!isEmpty(files) && (
      <Item mb={1}>
        <ContextualBox
          label={`Files (${files.coverLetter.length +
            files.manuscripts.length +
            files.supplementary.length})`}
          transparent
        >
          <ManuscriptFileList
            files={files}
            getSignedUrl={getSignedUrl}
            token={token}
          />
        </ContextualBox>
      </Item>
    )}
  </Fragment>
)

export default ManuscriptMetadata
