import { get } from 'lodash'
import { compose, withHandlers } from 'recompose'
import { withModal } from 'pubsweet-component-modal/src/components'

import { MultiAction } from './'

const OpenModal = ({ showModal, children }) => children(showModal)

export default compose(
  withModal(() => ({
    modalComponent: MultiAction,
  })),
  withHandlers({
    handleError: () => (fn, err) => e => {
      if (e.error) {
        fn(get(e, 'error.message', 'Oops! Something went wrong!'))
      }
      if (err) {
        fn(get(JSON.parse(e.response), 'error', 'Oops! Something went wrong!'))
      }
    },
  }),
  withHandlers({
    showModal: ({
      showModal,
      hideModal,
      handleError,
      setModalError,
      confirmAction,
      ...rest
    }) => e => {
      e.stopPropagation()
      showModal({
        onConfirm: () => {
          confirmAction().then(
            handleError(setModalError),
            handleError(setModalError, true),
          )
        },
        ...rest,
      })
    },
  }),
)(OpenModal)
